@@ -22,7 +22,7 @@ test_that("student-t distribution fitting and feedback works",{
   m <- 10
   s <- 20
   tdftest <- 4
-  vals <- c(m - s, m , m + 2 * s)
+  vals <- c(m - s, m , m + s, m + 2 * s)
   myfit <- fitdist(vals, pt((vals-m)/s, tdftest ), tdf = tdftest)
   fb <- feedback(myfit, quantiles=c(0.05, 0.95), values = c(m -0.5*s, m+s))
   t.parameters <- unlist(myfit$Student.t)
@@ -37,6 +37,32 @@ test_that("student-t distribution fitting and feedback works",{
 })
 
 
+test_that("skew normal distribution fitting and feedback works",{
+  skip_on_cran()
+  xi <- 10
+  omega <- 5
+  alpha <- 4
+  probs <- c(0.25, 0.5, 0.75)
+  myfit <- fitdist(vals = sn::qsn(probs, xi = xi, omega = omega, alpha = alpha),
+                   probs = probs)
+  fb <- feedback(myfit, quantiles=c(0.05, 0.95), values = c(xi - omega,
+                                                            xi + omega))
+  skewnorm.parameters <- unlist(myfit$Skewnormal)
+  best.name <- as.character(unlist(myfit$best.fitting))
+  attributes(skewnorm.parameters) <- NULL
+  expect_equal(signif(skewnorm.parameters, 3), c(xi, omega, alpha))
+  expect_equal(best.name, "skewnormal")
+  expect_equal(fb$fitted.quantiles[, "skewnormal"], 
+               signif(sn::qsn(c(0.05, 0.95), xi = xi, omega = omega, alpha = alpha)
+                      ,3))
+  expect_equal(fb$fitted.probabilities[, "skewnormal"],
+               signif(sn::psn(c(xi - omega,
+                                xi + omega),
+                              xi = xi,
+                              omega = omega,
+                              alpha = alpha),3))
+})
+
 test_that("log-t distribution fitting and feedback works",{
   skip_on_cran()
   m <- log(30)
@@ -61,7 +87,7 @@ test_that("mirror log-t distribution fitting and feedback works",{
   m <- log(30)
   s <- 0.5
   tdftest <- 5
-  vals <- c(22, 30, 42)
+  vals <- c(22, 30, 35, 42)
   u <- 60
   myfit <- fitdist(vals, 1 - pt((log(u - vals) - m) / s, tdftest ), lower = 0, tdf = tdftest,
                    upper = u)
@@ -85,7 +111,7 @@ test_that("scaled beta distribution fitting and feedback works",{
   b <- 20
   l <- 10
   u <- 60
-  vals <- c(18, 20, 24)
+  vals <- c(18, 20, 22, 24)
   myfit <- fitdist(vals, pbeta((vals-l)/(u-l), a, b ), lower = l, upper = u)
   fb <- feedback(myfit, quantiles=c(0.05, 0.95), values = c(19, 29))
   beta.parameters <- unlist(myfit$Beta)
@@ -183,7 +209,7 @@ test_that("mirror gamma distribution fitting and feedback works",{
   a <- 50
   b <- 2
   u <- 25
-  p <- c(0.25, 0.5 , 0.75)
+  p <- c(0.25, 0.5 , 0.6, 0.75)
   v <- u - qgamma(1 - p, a, b)
   myfit <- fitdist(vals = v, probs = p, lower = -10,
                    upper = u)
@@ -304,66 +330,3 @@ test_that("precision fitting works - lognormal",{
 })
 
 
-test_that("linear pooling works",{
-  skip_on_cran()
-  #p1 <- c(runif(1, 0.1, 0.4), 0.5, runif(1, 0.6, 0.9))
-  p1 <- c(0.25, 0.5, 0.75)
-  a <- 10; b <- 4
-  v1 <- qgamma(p1, a, b)
-  mu <- 3 ; sigma <- 2
-  v2 <- qnorm(p1, mu, sigma)
-  v3 <- qlnorm(p1, log(mu), sigma)
-  V <- matrix(c(v1, v2, v3), 3, 3)
-  myfit <- fitdist(vals = V, probs = p1, lower = 0)
-  
-  w1 <- 1/6; w2 <- 2/6; w3 <- 3/6
-  xtest <- 1.5
-  qu <- 0.95
-  
-  qlp <- qlinearpool(myfit, qu, w = c(w1, w2, w3))
-  qcheck <- w1 * pgamma(qlp, a, b) + 
-    w2 * pnorm(qlp, mu, sigma) +
-    w3 * plnorm(qlp, log(mu), sigma)
-  expect_equal(qcheck, qu , tolerance = 1e-4)
-  
-  expect_equal(plinearpool(myfit, qlp, w = c(w1, w2, w3)),
-               qu , tolerance = 1e-4)
-  
-  plp <- plinearpool(myfit, x = xtest, w = c(w1, w2, w3))
-  pcheck <- w1 * pgamma(xtest, a, b) + 
-    w2 * pnorm(xtest, mu, sigma) +
-    w3 * plnorm(xtest, log(mu), sigma)
-  expect_equal(plp, pcheck , tolerance = 1e-4)
-})
-
-test_that("linear pooling works - different lower limits",{
-  skip_on_cran()
-  llimits <- c(-2, 1, -4)
-  p1 <- c(0.25, 0.5, 0.6, 0.75)
-  a <- 10; b <- 4
-  v1 <- llimits[1] + qgamma(p1, a, b)
-  mu <- 3 ; sigma <- 2
-  v2 <- llimits[2] + qlnorm(p1, log(mu), sigma)
-  v3 <- llimits[3] + exp(1 + 2 * qt(p1, 3))
-  V <- matrix(c(v1, v2, v3), length(p1), 3)
-  myfit <- fitdist(vals = V, probs = p1, lower = llimits)
-  
-  w1 <- 1/6; w2 <- 2/6; w3 <- 3/6
-  xtest <- 3
-  qu <- 0.03
-  
-  qlp <- qlinearpool(myfit, qu, w = c(w1, w2, w3))
-  qcheck <- w1 * pgamma(qlp - llimits[1], a, b) + 
-    w2 * plnorm(qlp - llimits[2], log(mu), sigma) +
-    w3 * pt((log(qlp - llimits[3]) - 1) / 2 , 3)
-  expect_equal(qcheck, qu , tolerance = 1e-4)
-  
-  expect_equal(plinearpool(myfit, qlp, w = c(w1, w2, w3)),
-               qu , tolerance = 1e-4)
-  
-  plp <- plinearpool(myfit, x = xtest, w = c(w1, w2, w3))
-  pcheck <- w1 * pgamma(xtest - llimits[1], a, b) + 
-    w2 * plnorm(xtest - llimits[2], log(mu), sigma) +
-    w3 * pt((log(xtest - llimits[3]) - 1) / 2, 3)
-  expect_equal(plp, pcheck , tolerance = 1e-4)
-})
